@@ -15,7 +15,7 @@ from sqlalchemy import event
 from sqlalchemy.inspection import inspect
 from sqlalchemy.sql.expression import case
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 
 Image.LOAD_TRUNCATED_IMAGES = True  # this stops truncated image errors on large image files
 
@@ -162,16 +162,18 @@ class ImageSearch(object):
         thread = threading.Thread(target=background_setup)  # run this in the background
         thread.start()
 
-    def register(self, url_column='url', id_col=None, fk_cols=None):
+    def register(self, url_column='url', ignore_column='image_search_ignore', id_col=None, fk_cols=None):
         """
         decorator for registering models to be indexed. adds event listener for model changes
 
         :param url_column: the column where the url is located
         :type url_column: str
+        :param ignore_column: the column to determin if the image can be indexed
+        :type ignore_column: str
         :param id_col: the name of the id column to be used
         :type id_col: str
         :param fk_cols: list of the names foreign keys to be tracked
-        :type url_column: list[int]
+        :type fk_cols: list[string]
         """
         if fk_cols is None:
             fk_cols = []
@@ -193,6 +195,7 @@ class ImageSearch(object):
                 self.models[model.__tablename__] = SimpleNamespace(
                     data={},  # this stores image features
                     url_column=url_column,
+                    ignore_column=ignore_column,
                     saver=self.safe_save.saver(feature_file),  # create safe_save saver for saving to the file
                     id_column=id_col or inspect(model).primary_key[0].name,
                     fk_columns=fk_cols
@@ -256,8 +259,11 @@ class ImageSearch(object):
 
         data = self.models[entry.__tablename__]
 
-        image_id = "_".join(
-            [str(getattr(entry, id_column)) for id_column in [data.id_column] + data.fk_columns])
+        if hasattr(entry, data.ignore_column) and getattr(entry, data.ignore_column):
+            # the image is ignored therefor don't index it
+            return False
+
+        image_id = "_".join([str(getattr(entry, id_column)) for id_column in [data.id_column] + data.fk_columns])
 
         image_path = getattr(entry, data.url_column)
 
